@@ -13,15 +13,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import json
 import sys
 
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils as osc_utils
 from oslo_log import log as logging
+from oslo_serialization import jsonutils as json
 
-from saharaclient.osc.v1 import utils
+from saharaclient.osc import utils
 
 CT_FIELDS = ['id', 'name', 'plugin_name', 'plugin_version', 'description',
              'node_groups', 'anti_affinity', 'use_autoconfig', 'is_default',
@@ -107,7 +107,7 @@ class CreateClusterTemplate(command.ShowOne):
             action='store_true',
             default=False,
             help='Make the cluster template public (Visible from other '
-                 'tenants)',
+                 'projects)',
         )
         parser.add_argument(
             '--protected',
@@ -141,7 +141,7 @@ class CreateClusterTemplate(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
 
         if parsed_args.json:
@@ -243,7 +243,7 @@ class ListClusterTemplates(command.Lister):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
         search_opts = {}
         if parsed_args.plugin:
@@ -295,7 +295,7 @@ class ShowClusterTemplate(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
 
         data = utils.get_resource(
@@ -324,7 +324,7 @@ class DeleteClusterTemplate(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
         for ct in parsed_args.cluster_template:
             ct_id = utils.get_resource_id(client.cluster_templates, ct)
@@ -391,7 +391,7 @@ class UpdateClusterTemplate(command.ShowOne):
             '--public',
             action='store_true',
             help='Make the cluster template public '
-                 '(Visible from other tenants)',
+                 '(Visible from other projects)',
             dest='is_public'
         )
         public.add_argument(
@@ -443,7 +443,7 @@ class UpdateClusterTemplate(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
 
         ct_id = utils.get_resource_id(
@@ -506,3 +506,120 @@ class UpdateClusterTemplate(command.ShowOne):
         data = utils.prepare_data(data, CT_FIELDS)
 
         return self.dict2columns(data)
+
+
+class ImportClusterTemplate(command.ShowOne):
+    """Imports cluster template"""
+
+    log = logging.getLogger(__name__ + ".ImportClusterTemplate")
+
+    def get_parser(self, prog_name):
+        parser = super(ImportClusterTemplate, self).get_parser(prog_name)
+
+        parser.add_argument(
+            'json',
+            metavar="<json>",
+            help="JSON containing cluster template",
+        )
+        parser.add_argument(
+            '--name',
+            metavar="<name>",
+            help="Name of the cluster template",
+        )
+        parser.add_argument(
+            '--default-image-id',
+            metavar="<default_image_id>",
+            help="Default image ID to be used",
+        )
+        parser.add_argument(
+            '--node-groups',
+            metavar="<node-group:instances_count>",
+            nargs="+",
+            required=True,
+            help="List of the node groups(names or IDs) and numbers of "
+                 "instances for each one of them"
+        )
+        return parser
+
+    def take_action(self, parsed_args):
+        self.log.debug("take_action(%s)", parsed_args)
+        client = self.app.client_manager.data_processing
+
+        if (not parsed_args.node_groups):
+            raise exceptions.CommandError('--node_groups should be specified')
+
+        blob = osc_utils.read_blob_file_contents(parsed_args.json)
+        try:
+            template = json.loads(blob)
+        except ValueError as e:
+            raise exceptions.CommandError(
+                'An error occurred when reading '
+                'template from file %s: %s' % (parsed_args.json, e))
+
+        if parsed_args.default_image_id:
+            template['cluster_template']['default_image_id'] = (
+                parsed_args.default_image_id)
+        else:
+            template['cluster_template']['default_image_id'] = None
+
+        if parsed_args.name:
+            template['cluster_template']['name'] = parsed_args.name
+
+        if 'neutron_management_network' in template['cluster_template']:
+            template['cluster_template']['net_id'] = (
+                template['cluster_template'].pop('neutron_management_network'))
+
+        plugin, plugin_version, node_groups = _configure_node_groups(
+            parsed_args.node_groups, client)
+        if (('plugin_version' in template['cluster_template'] and
+                template['cluster_template']['plugin_version'] !=
+                plugin_version) or
+                ('plugin' in template['cluster_template'] and
+                    template['cluster_template']['plugin'] != plugin)):
+            raise exceptions.CommandError(
+                'Plugin of plugin version do not match between template '
+                'and given node group templates')
+        template['cluster_template']['node_groups'] = node_groups
+
+        data = client.cluster_templates.create(
+            **template['cluster_template']).to_dict()
+
+        _format_ct_output(data)
+        data = utils.prepare_data(data, CT_FIELDS)
+
+        return self.dict2columns(data)
+
+
+class ExportClusterTemplate(command.Command):
+    """Export cluster template to JSON"""
+
+    log = logging.getLogger(__name__ + ".ExportClusterTemplate")
+
+    def get_parser(self, prog_name):
+        parser = super(ExportClusterTemplate, self).get_parser(prog_name)
+        parser.add_argument(
+            "cluster_template",
+            metavar="<cluster-template>",
+            help="Name or id of the cluster template to export",
+        )
+        parser.add_argument(
+            "--file",
+            metavar="<filename>",
+            help="Name of the file cluster template should be exported to "
+                 "If not provided, print to stdout"
+        )
+
+        return parser
+
+    def take_action(self, parsed_args):
+        self.log.debug("take_action(%s)", parsed_args)
+        client = self.app.client_manager.data_processing
+        ngt_id = utils.get_resource_id(
+            client.cluster_templates, parsed_args.cluster_template)
+        response = client.cluster_templates.export(ngt_id)
+        result = json.dumps(response._info, indent=4)+"\n"
+        if parsed_args.file:
+            with open(parsed_args.file, "w+") as file:
+                file.write(result)
+        else:
+            sys.stdout.write(result)
