@@ -13,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import json
 import sys
 
 from osc_lib.command import command
@@ -22,10 +21,10 @@ from osc_lib import utils as osc_utils
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
 
-from saharaclient.osc.v1 import utils
+from saharaclient.osc import utils
 
 CLUSTER_FIELDS = ["cluster_template_id", "use_autoconfig", "user_keypair_id",
-                  "status", "image", "node_groups", "id",
+                  "status", "image", "node_groups", "id", "info",
                   "anti_affinity", "plugin_version", "name", "is_transient",
                   "is_protected", "description", "is_public",
                   "neutron_management_network", "plugin_name"]
@@ -111,7 +110,7 @@ class CreateCluster(command.ShowOne):
             '--public',
             action='store_true',
             default=False,
-            help='Make the cluster public (Visible from other tenants)',
+            help='Make the cluster public (Visible from other projects)',
         )
         parser.add_argument(
             '--protected',
@@ -142,14 +141,14 @@ class CreateCluster(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
         network_client = self.app.client_manager.network
 
         if parsed_args.json:
             blob = osc_utils.read_blob_file_contents(parsed_args.json)
             try:
-                template = json.loads(blob)
+                template = jsonutils.loads(blob)
             except ValueError as e:
                 raise exceptions.CommandError(
                     'An error occurred when reading '
@@ -203,7 +202,7 @@ class CreateCluster(command.ShowOne):
                     if not osc_utils.wait_for_status(
                             client.clusters.get, cluster.id):
                         self.log.error(
-                            'Error occurred during cluster creation: %s' %
+                            'Error occurred during cluster creation: %s',
                             data['id'])
 
             data = {}
@@ -215,7 +214,7 @@ class CreateCluster(command.ShowOne):
                 if not osc_utils.wait_for_status(
                         client.clusters.get, data['id']):
                     self.log.error(
-                        'Error occurred during cluster creation: %s' %
+                        'Error occurred during cluster creation: %s',
                         data['id'])
                 data = client.clusters.get(data['id']).to_dict()
             _format_cluster_output(data)
@@ -259,7 +258,7 @@ class ListClusters(command.Lister):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
         search_opts = {}
         if parsed_args.plugin:
@@ -328,7 +327,7 @@ class ShowCluster(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
 
         kwargs = {}
@@ -395,7 +394,7 @@ class DeleteCluster(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
         clusters = []
         for cluster in parsed_args.cluster:
@@ -451,7 +450,7 @@ class UpdateCluster(command.ShowOne):
             '--public',
             action='store_true',
             help='Make the cluster public '
-                 '(Visible from other tenants)',
+                 '(Visible from other projects)',
             dest='is_public'
         )
         public.add_argument(
@@ -479,7 +478,7 @@ class UpdateCluster(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
 
         cluster_id = utils.get_resource_id(
@@ -489,7 +488,7 @@ class UpdateCluster(command.ShowOne):
         if parsed_args.shares:
             blob = osc_utils.read_blob_file_contents(parsed_args.shares)
             try:
-                shares = json.loads(blob)
+                shares = jsonutils.loads(blob)
             except ValueError as e:
                 raise exceptions.CommandError(
                     'An error occurred when reading '
@@ -547,7 +546,7 @@ class ScaleCluster(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
 
         cluster = utils.get_resource(
@@ -556,13 +555,13 @@ class ScaleCluster(command.ShowOne):
         if parsed_args.json:
             blob = osc_utils.read_blob_file_contents(parsed_args.json)
             try:
-                template = json.loads(blob)
+                template = jsonutils.loads(blob)
             except ValueError as e:
                 raise exceptions.CommandError(
                     'An error occurred when reading '
                     'template from file %s: %s' % (parsed_args.json, e))
 
-            data = client.clusters.scale(cluster.id, template).to_dict()
+            data = client.clusters.scale(cluster.id, template).cluster
         else:
             scale_object = {
                 "add_node_groups": [],
@@ -602,7 +601,7 @@ class ScaleCluster(command.ShowOne):
                 self.log.error(
                     'Error occurred during cluster scaling: %s' %
                     cluster.id)
-            data = client.clusters.get(cluster.id).to_dict()
+            data = client.clusters.get(cluster.id).cluster
 
         _format_cluster_output(data)
         data = utils.prepare_data(data, CLUSTER_FIELDS)
@@ -639,7 +638,7 @@ class VerificationUpdateCluster(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
 
         if parsed_args.show:
@@ -657,7 +656,7 @@ class VerificationUpdateCluster(command.ShowOne):
                 print_status = 'started'
             sys.stdout.write(
                 'Cluster "{cluster}" health verification has been '
-                '{status}.'.format(cluster=parsed_args.cluster,
-                                   status=print_status))
+                '{status}.\n'.format(cluster=parsed_args.cluster,
+                                     status=print_status))
 
             return {}, {}
