@@ -23,7 +23,7 @@ from oslo_log import log as logging
 from oslo_serialization import jsonutils
 
 from saharaclient.api import base
-from saharaclient.osc.v1 import utils
+from saharaclient.osc import utils
 
 JOB_BINARY_FIELDS = ['name', 'id', 'url', 'description', 'is_public',
                      'is_protected']
@@ -60,23 +60,46 @@ class CreateJobBinary(command.ShowOne):
             metavar="<description>",
             help="Description of the job binary"
         )
-        parser.add_argument(
+        username = parser.add_mutually_exclusive_group()
+        username.add_argument(
             '--username',
             metavar='<username>',
             help='Username for accessing the job binary URL',
         )
+        username.add_argument(
+            '--access-key',
+            metavar='<accesskey>',
+            help='S3 access key for accessing the job binary URL',
+        )
         password = parser.add_mutually_exclusive_group()
         password.add_argument(
             '--password',
             metavar='<password>',
             help='Password for accessing the job binary URL',
         )
+        password.add_argument(
+            '--secret-key',
+            metavar='<secretkey>',
+            help='S3 secret key for accessing the job binary URL',
+        )
         password.add_argument(
             '--password-prompt',
             dest="password_prompt",
             action="store_true",
             help='Prompt interactively for password',
         )
+        password.add_argument(
+            '--secret-key-prompt',
+            dest="secret_key_prompt",
+            action="store_true",
+            help='Prompt interactively for S3 secret key',
+        )
+        parser.add_argument(
+            '--s3-endpoint',
+            metavar='<endpoint>',
+            help='S3 endpoint for accessing the job binary URL (ignored if '
+                 'binary not in S3',
+        )
         parser.add_argument(
             '--public',
             action='store_true',
@@ -99,7 +122,7 @@ class CreateJobBinary(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
 
         if parsed_args.json:
@@ -122,20 +145,47 @@ class CreateJobBinary(command.ShowOne):
                 parsed_args.password = osc_utils.get_password(
                     self.app.stdin, confirm=False)
 
+            if parsed_args.secret_key_prompt:
+                parsed_args.secret_key = osc_utils.get_password(
+                    self.app.stdin, confirm=False)
+
+            if not parsed_args.password:
+                parsed_args.password = parsed_args.secret_key
+
+            if not parsed_args.username:
+                parsed_args.username = parsed_args.access_key
+
             if parsed_args.password and not parsed_args.username:
                 raise exceptions.CommandError(
-                    'Username via --username should be provided with password')
+                    'Username via --username, or S3 access key via '
+                    '--access-key should be provided with password')
 
             if parsed_args.username and not parsed_args.password:
                 raise exceptions.CommandError(
-                    'Password should be provided via --password or entered '
-                    'interactively with --password-prompt')
+                    'Password should be provided via --password or '
+                    '--secret-key, or entered interactively with '
+                    '--password-prompt or --secret-key-prompt')
 
             if parsed_args.password and parsed_args.username:
-                extra = {
-                    'user': parsed_args.username,
-                    'password': parsed_args.password
-                }
+                if not parsed_args.url:
+                    raise exceptions.CommandError(
+                        'URL must be provided via --url')
+                if parsed_args.url.startswith('s3'):
+                    if not parsed_args.s3_endpoint:
+                        raise exceptions.CommandError(
+                            'S3 job binaries need an endpoint provided via '
+                            '--s3-endpoint')
+                    extra = {
+                        'accesskey': parsed_args.username,
+                        'secretkey': parsed_args.password,
+                        'endpoint': parsed_args.s3_endpoint,
+                    }
+
+                else:
+                    extra = {
+                        'user': parsed_args.username,
+                        'password': parsed_args.password
+                    }
             else:
                 extra = None
 
@@ -173,7 +223,7 @@ class ListJobBinaries(command.Lister):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
 
         data = client.job_binaries.list()
@@ -215,7 +265,7 @@ class ShowJobBinary(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
 
         data = utils.get_resource(
@@ -243,7 +293,7 @@ class DeleteJobBinary(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
         for jb in parsed_args.job_binary:
             jb = utils.get_resource(client.job_binaries, jb)
@@ -290,34 +340,58 @@ class UpdateJobBinary(command.ShowOne):
             metavar="<description>",
             help='Description of the job binary'
         )
-        parser.add_argument(
+        username = parser.add_mutually_exclusive_group()
+        username.add_argument(
             '--username',
             metavar='<username>',
             help='Username for accessing the job binary URL',
         )
+        username.add_argument(
+            '--access-key',
+            metavar='<accesskey>',
+            help='S3 access key for accessing the job binary URL',
+        )
         password = parser.add_mutually_exclusive_group()
         password.add_argument(
             '--password',
             metavar='<password>',
             help='Password for accessing the job binary URL',
         )
+        password.add_argument(
+            '--secret-key',
+            metavar='<secretkey>',
+            help='S3 secret key for accessing the job binary URL',
+        )
         password.add_argument(
             '--password-prompt',
             dest="password_prompt",
             action="store_true",
             help='Prompt interactively for password',
         )
+        password.add_argument(
+            '--secret-key-prompt',
+            dest="secret_key_prompt",
+            action="store_true",
+            help='Prompt interactively for S3 secret key',
+        )
+        parser.add_argument(
+            '--s3-endpoint',
+            metavar='<endpoint>',
+            help='S3 endpoint for accessing the job binary URL (ignored if '
+                 'binary not in S3',
+        )
         public = parser.add_mutually_exclusive_group()
         public.add_argument(
             '--public',
             action='store_true',
-            help='Make the job binary public (Visible from other tenants)',
+            help='Make the job binary public (Visible from other projects)',
             dest='is_public'
         )
         public.add_argument(
             '--private',
             action='store_false',
-            help='Make the job binary private (Visible only from this tenant)',
+            help='Make the job binary private (Visible only from'
+                 ' this project)',
             dest='is_public'
         )
         protected = parser.add_mutually_exclusive_group()
@@ -345,7 +419,7 @@ class UpdateJobBinary(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
 
         jb_id = utils.get_resource_id(
@@ -364,12 +438,21 @@ class UpdateJobBinary(command.ShowOne):
             if parsed_args.password_prompt:
                 parsed_args.password = osc_utils.get_password(
                     self.app.stdin, confirm=False)
+            if parsed_args.secret_key_prompt:
+                parsed_args.secret_key = osc_utils.get_password(
+                    self.app.stdin, confirm=False)
 
             extra = {}
             if parsed_args.password:
                 extra['password'] = parsed_args.password
             if parsed_args.username:
                 extra['user'] = parsed_args.username
+            if parsed_args.access_key:
+                extra['accesskey'] = parsed_args.access_key
+            if parsed_args.secret_key:
+                extra['secretkey'] = parsed_args.secret_key
+            if parsed_args.s3_endpoint:
+                extra['endpoint'] = parsed_args.s3_endpoint
             if not extra:
                 extra = None
 
@@ -408,20 +491,21 @@ class DownloadJobBinary(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
 
         if not parsed_args.file:
             parsed_args.file = parsed_args.job_binary
 
-        jb_id = utils.get_resource_id(
-            client.job_binaries, parsed_args.job_binary)
-        data = client.job_binaries.get_file(jb_id)
-
         if path.exists(parsed_args.file):
-            self.log.error('File "%s" already exists. Chose another one with '
-                           '--file argument.' % parsed_args.file)
+            msg = ('File "%s" already exists. Chose another one with '
+                   '--file argument.' % parsed_args.file)
+            raise exceptions.CommandError(msg)
         else:
+            jb_id = utils.get_resource_id(
+                client.job_binaries, parsed_args.job_binary)
+            data = client.job_binaries.get_file(jb_id)
+
             with open(parsed_args.file, 'w') as f:
                 f.write(data)
             sys.stdout.write(
