@@ -21,7 +21,7 @@ from osc_lib import utils as osc_utils
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
 
-from saharaclient.osc.v1 import utils
+from saharaclient.osc import utils
 
 JOB_FIELDS = ['id', 'job_template_id', 'cluster_id', 'input_id', 'output_id',
               'start_time', 'end_time', 'status', 'is_public', 'is_protected',
@@ -117,7 +117,7 @@ class ExecuteJob(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
 
         if parsed_args.json:
@@ -174,11 +174,16 @@ class ExecuteJob(command.ShowOne):
                 client.jobs, parsed_args.job_template)
             cluster_id = utils.get_resource_id(
                 client.clusters, parsed_args.cluster)
-
-            input_id = utils.get_resource_id(
-                client.data_sources, parsed_args.input)
-            output_id = utils.get_resource_id(
-                client.data_sources, parsed_args.output)
+            if parsed_args.input not in [None, "", "None"]:
+                input_id = utils.get_resource_id(
+                    client.data_sources, parsed_args.input)
+            else:
+                input_id = None
+            if parsed_args.output not in [None, "", "None"]:
+                output_id = utils.get_resource_id(
+                    client.data_sources, parsed_args.output)
+            else:
+                output_id = None
 
             data = client.job_executions.create(
                 job_id=jt_id, cluster_id=cluster_id, input_id=input_id,
@@ -219,7 +224,7 @@ class ListJobs(command.Lister):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
 
         data = client.job_executions.list()
@@ -265,7 +270,7 @@ class ShowJob(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
 
         data = client.job_executions.get(parsed_args.job).to_dict()
@@ -299,7 +304,7 @@ class DeleteJob(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
         for job_id in parsed_args.job:
             client.job_executions.delete(job_id)
@@ -335,13 +340,13 @@ class UpdateJob(command.ShowOne):
         public.add_argument(
             '--public',
             action='store_true',
-            help='Make the job public (Visible from other tenants)',
+            help='Make the job public (Visible from other projects)',
             dest='is_public'
         )
         public.add_argument(
             '--private',
             action='store_false',
-            help='Make the job private (Visible only from this tenant)',
+            help='Make the job private (Visible only from this project)',
             dest='is_public'
         )
         protected = parser.add_mutually_exclusive_group()
@@ -363,7 +368,7 @@ class UpdateJob(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug("take_action(%s)" % parsed_args)
+        self.log.debug("take_action(%s)", parsed_args)
         client = self.app.client_manager.data_processing
 
         update_dict = utils.create_dict_from_kwargs(
